@@ -7,14 +7,13 @@ from enum import Enum, auto
 from functools import wraps
 from typing import Callable, List, Optional
 
-try:
-    from typing import Final, TypedDict
-except ImportError:
-    from typing_extensions import Final, TypedDict  # type: ignore[misc]
-
 from opentelemetry.propagate import extract
 from opentelemetry.trace import Span, SpanKind, get_current_span, get_tracer, use_span
 from opentelemetry.util import types
+from typing_extensions import (  # uses actual 'typing' module if available
+    Final,
+    TypedDict,
+)
 
 from .propagations import extract_links_carrier
 from .utils import LOGGER, FunctionInspector, P, T
